@@ -18,7 +18,6 @@
 """File conftest.py for pytest test suite."""
 
 from typing import Callable
-from collections import OrderedDict
 
 import pytest
 import flexmock
@@ -151,14 +150,14 @@ def resolver(pipeline_config: PipelineConfig, project: Project, predictor_mock:
 def _get_state() -> State:
     """Create a fixture for a non-final state."""
     unresolved_dependency = ("flask", "1.1.1", "https://pypi.org/simple")
-    unresolved_dependencies = OrderedDict([(id(unresolved_dependency), unresolved_dependency)])
+    unresolved_dependencies = {id(unresolved_dependency): unresolved_dependency}
     state = State(
         score=0.1,
-        unresolved_dependencies=OrderedDict({"flask": unresolved_dependencies}),
-        resolved_dependencies=OrderedDict({"hexsticker": ("hexsticker", "1.0.0", "https://pypi.org/simple")}),
+        unresolved_dependencies={"flask": unresolved_dependencies},
+        resolved_dependencies={"hexsticker": ("hexsticker", "1.0.0", "https://pypi.org/simple")},
         advised_runtime_environment=RuntimeEnvironment.from_dict({"python_version": "3.6"}),
     )
-    state.add_justification([{"foo": "bar"}, {"bar": "baz"}])
+    state.add_justification(AdviserTestCase.JUSTIFICATION_SAMPLE_1)
     return state
 
 
@@ -187,3 +186,16 @@ def builder_context(project: Project) -> PipelineBuilderContext:
         decision_type=None,
         recommendation_type=RecommendationType.LATEST,
     )
+
+
+@pytest.fixture(scope="session", autouse=True)
+def state_verify_justification_schema() -> None:
+    """Set automatic checks for schema validation for justifications added to states by pipeline units."""
+    # Patch the justification function.
+    def _patched_add_justification(self, justification):
+        """Patch State.add_justification."""
+        AdviserTestCase.verify_justification_schema(justification)
+        add_justification_func(self, justification)
+
+    add_justification_func = State.add_justification
+    State.add_justification = _patched_add_justification
