@@ -22,7 +22,6 @@ from typing import Any
 from typing import Dict
 from typing import Generator
 from typing import List
-from typing import TYPE_CHECKING
 from typing import Union
 
 import attr
@@ -33,10 +32,12 @@ from .exceptions import PipelineUnitError
 from .sieve import Sieve
 from .step import Step
 from .stride import Stride
-from .unit import Unit
 from .wrap import Wrap
 
+from typing import TYPE_CHECKING
+
 if TYPE_CHECKING:
+    from .unit import Unit
     from .report import Report
 
 
@@ -60,11 +61,13 @@ class PipelineConfig:
             "wraps": [wrap.to_dict() for wrap in self.wraps],
         }
 
-    def iter_units(self) -> Generator["Unit", None, None]:
+    def iter_units(self):
+        # type:('PipelineConfig') -> Generator[Unit, None, None]
         """Iterate over units present in the configuration."""
         yield from chain(self.boots, self.sieves, self.steps, self.strides, self.wraps)
 
-    def iter_units_reversed(self) -> Generator["Unit", None, None]:
+    def iter_units_reversed(self):
+        # type:('PipelineConfig') -> Generator[Unit, None, None]
         """Iterate over units present in the configuration in a reversed order."""
         yield from reversed(self.wraps)
         yield from reversed(self.strides)
@@ -79,9 +82,7 @@ class PipelineConfig:
                 unit.pre_run()
             except Exception as exc:
                 raise PipelineUnitError(
-                    "Failed to run pre_run method on unit %r: %s",
-                    unit.__class__.__name__,
-                    str(exc),
+                    "Failed to run pre_run method on unit %r: %s", unit.__class__.__name__, str(exc),
                 ) from exc
 
     def call_post_run(self) -> None:
@@ -91,21 +92,16 @@ class PipelineConfig:
                 unit.post_run()
             except Exception as exc:
                 raise PipelineUnitError(
-                    "Failed to run post_run method on unit %r: %s",
-                    unit.__class__.__name__,
-                    str(exc),
+                    "Failed to run post_run method on unit %r: %s", unit.__class__.__name__, str(exc),
                 ) from exc
 
-    def call_post_run_report(
-        self, report: Union["Report", DependencyMonkeyReport]
-    ) -> None:
+    def call_post_run_report(self, report):
+        # type:('PipelineConfig', Union[Report, DependencyMonkeyReport]) -> None
         """Call post-run method when report is generated."""
         for unit in self.iter_units_reversed():
             try:
                 unit.post_run_report(report)
             except Exception as exc:
                 raise PipelineUnitError(
-                    "Failed to run pre_run_report method on unit %r: %s",
-                    unit.__class__.__name__,
-                    str(exc),
+                    "Failed to run pre_run_report method on unit %r: %s", unit.__class__.__name__, str(exc),
                 ) from exc
