@@ -44,6 +44,28 @@ class State:
     resolved_dependencies = attr.ib(default=attr.Factory(dict))  # type: Dict[str, Tuple[str, str, str]]
     _parent = attr.ib(default=None)  # type: weakref.ReferenceType['State']
     advised_runtime_environment = attr.ib(type=Optional[RuntimeEnvironment], kw_only=True, default=None)
+    # See RFC-6902:
+    #   https://tools.ietf.org/html/rfc6902
+    # An example entry for a manifest change:
+    #   [
+    #     {
+    #       "apiVersion:": "apps.openshift.io/v1",
+    #       "kind": "DeploymentConfig",
+    #       "patch": {
+    #         "op": "add",
+    #         "path": "spec.template.spec.containers[0].env",
+    #         "value": {"name": "OMP_NUM_THREADS", "value": "1"},
+    #       }
+    #     }
+    #   ]
+    # See available yaml-patch operations at https://python-json-patch.readthedocs.io/en/latest/tutorial.html
+    #
+    # Each entry is a list of JSON patches to be applied. If any entry fails to
+    # patch, the patching can continue with the subsequent JSON patch as each
+    # entry corresponds to a list of atomic changes to be applied:
+    #
+    #  https://tools.ietf.org/html/rfc6902#section-5
+    advised_manifest_changes = attr.ib(type=List[List[Dict[str, Any]]], kw_only=True, default=attr.Factory(list))
     justification = attr.ib(type=List[Dict[str, str]], default=attr.Factory(list), kw_only=True)
 
     _EPSILON = 0.1
@@ -86,6 +108,7 @@ class State:
 
         # Parent is removed intentionally.
         return {
+            "advised_manifest_changes": self.advised_manifest_changes,
             "advised_runtime_environment": advised_runtime_environment,
             "iteration": self.iteration,
             "justification": self.justification,
@@ -296,6 +319,7 @@ class State:
             unresolved_dependencies=unresolved_dependencies,
             resolved_dependencies=self.resolved_dependencies.copy(),
             advised_runtime_environment=cloned_advised_environment,
+            advised_manifest_changes=self.advised_manifest_changes.copy(),
             justification=self.justification.copy(),
             parent=weakref.ref(self),
         )
